@@ -2,10 +2,10 @@
 /*                                                                           */
 /* This file is part of the SYMPHONY MILP Solver Framework.                  */
 /*                                                                           */
-/* SYMPHONY was jointly developed by Ted Ralphs (tkralphs@lehigh.edu) and    */
+/* SYMPHONY was jointly developed by Ted Ralphs (ted@lehigh.edu) and         */
 /* Laci Ladanyi (ladanyi@us.ibm.com).                                        */
 /*                                                                           */
-/* (c) Copyright 2000-2007 Ted Ralphs. All Rights Reserved.                  */
+/* (c) Copyright 2000-2010 Ted Ralphs. All Rights Reserved.                  */
 /*                                                                           */
 /* This software is licensed under the Common Public License. Please see     */
 /* accompanying file for terms.                                              */
@@ -91,14 +91,17 @@ COMMAND parameter_commands[] = {
   { "find_first_feasible" },
   { "generate_cgl_cuts" },
   { "generate_cgl_gomory_cuts" },
+  { "generate_cgl_redsplit_cuts" },
   { "generate_cgl_knapsack_cuts" },
   { "generate_cgl_oddhole_cuts" },
   { "generate_cgl_probing_cuts" },
   { "generate_cgl_clique_cuts" },
   { "generate_cgl_mir_cuts" },
+  { "generate_cgl_twomir_cuts" },
   { "generate_cgl_flow_and_cover_cuts" },
   { "generate_cgl_rounding_cuts" },
   { "generate_cgl_lift_and_project_cuts" },
+  { "generate_cgl_landp_cuts" },
   { "node_selection_rule" },
   { "strong_branching_candidate_num" },
   { "compare_candidadates_dafult" },
@@ -131,8 +134,8 @@ int main_level = 0; /* 0 - SYMPHONY:
 		       3 - SYMPHONY\Display\Parameter:
 		    */
 
-int sym_help(char *line);
-int sym_read_line(char *prompt, char **input);
+int sym_help(const char *line);
+int sym_read_line(const char *prompt, char **input);
 int sym_free_env(sym_environment *env);
 
 int main(int argc, char **argv)
@@ -147,7 +150,7 @@ int main(int argc, char **argv)
       sym_parse_command_line(env, argc, argv);
 
       if (env->par.verbosity >= 0){
-	 version();
+	 sym_version();
       }
       
       if (env->par.test){
@@ -169,7 +172,7 @@ int main(int argc, char **argv)
 	    printf("See sym_return_values.h for meaning of code.\n\n");
 	    exit(termcode);
 	 }
-
+	 printf("\n");
 	 sym_solve(env);
       }
    
@@ -186,11 +189,10 @@ int main(int argc, char **argv)
      double objval = 0.0, initial_time = 0.0, start_time = 0.0;
      double finish_time = 0.0, dbl_value = 0;
 
-     version();
-     printf("***** WELCOME TO SYMPHONY INTERACTIVE MIP SOLVER ******\n\n"
-	    "Please type 'help'/'?' to see the main commands!\n\n");
+     sym_version();
+     printf("Please type 'help'/'?' to see a list of commands\n\n");
 
-     env->par.verbosity = -1;
+     sym_set_int_param(env, "verbosity", -1);
 
 #ifdef HAS_READLINE
      sym_initialize_readline();
@@ -241,11 +243,13 @@ int main(int argc, char **argv)
 	    strcpy(ext, ""); 
 	 }
 
-	 if(!(strcmp(ext, "mod") == 0 || strcmp(ext, "mps") == 0 || strcmp(ext, "lpt") == 0)){
-	   while(true){
-	     sym_read_line("Type of the file ('mps'/'ampl'/'gmpl'/'lpt'): ", &line);
+	 if(!(strcmp(ext, "mod") == 0 || strcmp(ext, "mps") == 0 || strcmp(ext, "lpt") == 0
+	      || strcmp(ext, "lp") == 0)){
+	    while(true){
+	     sym_read_line("Type of the file ('mps'/'ampl'/'gmpl'/'lp'): ", &line);
 	     if(!(strcmp(line, "mps") == 0 || strcmp(line, "ampl") == 0 ||
-		  strcmp(line, "gmpl") == 0 || strcmp(line, "lpt") == 0 )){
+		  strcmp(line, "gmpl") == 0 || strcmp(line, "lp") == 0 || 
+		  strcmp(line, "lpt") == 0)){
 	       printf("Unknown type!\n");
 	       continue; 
 	     } else {
@@ -260,7 +264,7 @@ int main(int argc, char **argv)
 	    if(sym_read_mps(env, args[1])){
 	       continue;
 	    }
-	 }else if (strcmp(ext, "lpt") == 0){
+	 }else if (strcmp(ext, "lp") == 0 || strcmp(ext, "lpt") == 0){
 	    sym_free_env(env);
 	    if(sym_read_lp(env, args[1])){
 	       continue;
@@ -294,12 +298,14 @@ int main(int argc, char **argv)
 	 } 
 	 if(strcmp(args[0], "solve") == 0){
 	   start_time = wall_clock(NULL);
+	   printf("\n");
 	   termcode = sym_solve(env);
 	   finish_time = wall_clock(NULL);
 	 } else {
 	   is_int = env->mip->is_int;
 	   env->mip->is_int  = (char *)   calloc(CSIZE, env->mip->n);
 	   start_time = wall_clock(NULL);
+	   printf("\n");
 	   termcode = sym_solve(env);
 	   finish_time = wall_clock(NULL);
 	   env->mip->is_int = is_int;
@@ -419,10 +425,11 @@ int main(int argc, char **argv)
 	       
 	       print_statistics(&(env->warm_start->comp_times), 
 				&(env->warm_start->stat),
-				env->ub, env->lb, initial_time, 
-				start_time, finish_time,
+                                NULL,
+				env->warm_start->ub, env->warm_start->lb, 
+				initial_time, start_time, finish_time,
 				env->mip->obj_offset, env->mip->obj_sense,
-				env->has_ub);
+				env->warm_start->has_ub,NULL);
 	       printf("\n");	       
 	     }
 	     strcpy(args[1], "");	       
@@ -562,7 +569,7 @@ int main(int argc, char **argv)
 	 printf("Resetting...\n");
 	 sym_close_environment(env);
 	 env = sym_open_environment();
-	 env->par.verbosity = -1;
+	 sym_set_int_param(env, "verbosity", -1);
        } else if ((strcmp(args[0], "quit") == 0) ||
 		  (strcmp(args[0], "exit") == 0)){
 	 break;
@@ -583,7 +590,7 @@ int main(int argc, char **argv)
 /*===========================================================================*\
 \*===========================================================================*/
 
-int sym_help(char *line)
+int sym_help(const char *line)
 {    
   if(strcmp(line, "main_help") == 0){
 
@@ -601,21 +608,25 @@ int sym_help(char *line)
   } else if (strcmp(line, "set_help") == 0 || strcmp(line, "display_param_help") == 0){
 
     printf("\n\nList of parameters: \n\n"); 
-    printf("verbosity                          : set verbosity (default: 1)\n"
+    printf("verbosity                          : set verbosity (default: -1)\n"
 	   "upper_bound                        : use an initial upper bound\n"
 	   "find_first_feasible                : whether to find the first feasible solution or\n"
 	   "                                     to solve the optimality (default: 0) \n"
 	   "generate_cgl_cuts                  : whether or not to use cgl cuts (default: 1)\n"
-	   "generate_cgl_gomory_cuts           : whether or not to use cgl gomory cuts (default: 1)\n"
-	   "generate_cgl_knapsack_cuts         : whether or not to use cgl knapsack cuts (default: 1)\n"
-	   "generate_cgl_oddhole_cuts          : whether or not to use cgl oddhole cuts (default: 1)\n"
-	   "generate_cgl_probing_cuts          : whether or not to use cgl probing cuts (default: 1)\n"
-	   "generate_cgl_clique_cuts           : whether or not to use cgl clique cuts (default: 1)\n"	   
-	   "generate_cgl_mir_cuts              : whether or not to use cgl mixed integer rounding cuts\n" 
-           "                                     (default: 0)\n"
- 	   "generate_cgl_flow_and_cover_cuts   : whether or not to use cgl flow and cover cuts (default: 1)\n"
-	   "generate_cgl_rounding_cuts         : whether or not to use cgl rounding cuts (default: 0)\n"
-	   "generate_cgl_lift_and_project_cuts : whether or not to use cgl lift and project cuts (default: 0)\n"
+	   "generate_cgl_gomory_cuts           : set generation level of cgl gomory cuts (default: 0)\n"
+	   "generate_cgl_redsplit_cuts         : set generation level of cgl redsplit cuts (default: -1)\n"
+	   "generate_cgl_knapsack_cuts         : set generation level of cgl knapsack cuts (default: 0)\n"
+	   "generate_cgl_oddhole_cuts          : set generation level of cgl oddhole cuts (default: 0)\n"
+	   "generate_cgl_probing_cuts          : set generation level of cgl probing cuts (default: 0)\n"
+	   "generate_cgl_clique_cuts           : set generation level of cgl clique cuts (default: 0)\n"	   
+	   "generate_cgl_mir_cuts              : set generation level of cgl mixed integer rounding cuts\n" 
+           "                                     (default: -1)\n"
+	   "generate_cgl_twomir_cuts            : set generation level of cgl two-step mixed integer rounding cuts\n" 
+           "                                     (default: -1)\n"
+ 	   "generate_cgl_flow_and_cover_cuts   : set generation level of cgl flow and cover cuts (default: 0)\n"
+	   "generate_cgl_rounding_cuts         : set generation level of cgl rounding cuts (default: -1)\n"
+	   "generate_cgl_lift_and_project_cuts : set generation level of cgl lift and project cuts (default: -1)\n"
+	   "generate_cgl_landp_cuts            : set generation level of cgl lift and project cuts (default: -1)\n"
 	   "node_selection_rule                : set the node selection rule/search strategy (default: 5)\n"
 	   "strong_branching_candidate_num     : set the stong branching candidates number (default: var)\n"
 	   "compare_candidates_default         : set the rule to compare the candidates (defualt: 2)\n"
@@ -649,7 +660,7 @@ int sym_help(char *line)
 /*===========================================================================*\
 \*===========================================================================*/
 
-int sym_read_line(char *prompt, char **input)
+int sym_read_line(const char *prompt, char **input)
 {
 
 #ifndef HAS_READLINE
